@@ -1,19 +1,19 @@
-__version__ = '0.1.2'
-
+__version__ = '0.1.10'
 
 from ricco.coord_trans import BD2WGS
 from ricco.coord_trans import GD2WGS
 from ricco.gis_tools import circum_pio_num_geo_aoi
 from ricco.gis_tools import mark_tags_df
-from ricco.util import add
 from ricco.util import csv2shp
 from ricco.util import extract_num
 from ricco.util import mkdir_2
 from ricco.util import pinyin
 from ricco.util import rdf
 from ricco.util import reset2name
+from ricco.util import segment
 from ricco.util import serise_to_float
 from ricco.util import shp2csv
 from ricco.util import split_csv
+from ricco.util import to_csv_by_line
 from ricco.util import to_float
 from ricco.util import valid_check
